@@ -2,12 +2,14 @@
 import logging
 import logging.handlers
 import sys
-from typing import Mapping
+from typing import Literal, Mapping
 
 import loguru
 import tqdm
-from loguru import logger  # pylint: disable=W0611
-from typing_extensions import Literal
+from loguru import logger as logger_
+
+# This is my re-exported symbol. Silence linters
+logger = logger_
 
 LoguruLogLevel = Literal[
     "FATAL",
@@ -24,9 +26,19 @@ _verbosity_int_to_str: Mapping[int, LoguruLogLevel] = {0: "INFO", 1: "DEBUG", 2:
 def verbosity_int_to_str(verbosity: int) -> LoguruLogLevel:
     """
     Map a verbosity integer to the corresponding Loguru Level.
-    :param verbosity: 0 for >= INFO,
-                      1 for >= DEBUG,
-                      2 for >= TRACE
+    :param verbosity: = 0 -> INFO,
+                      = 1 -> DEBUG,
+                      >=2 -> TRACE
+
+    >>> verbosity_int_to_str(1)
+    'DEBUG'
+    >>> verbosity_int_to_str(2)
+    'TRACE'
+    >>> verbosity_int_to_str(3)
+    'TRACE'
+    >>> verbosity_int_to_str(-1)
+    Traceback (most recent call last):
+    RuntimeError: ...
     """
     if verbosity < 0:
         raise RuntimeError("verbosity must be >= 0")
@@ -47,7 +59,7 @@ def loguru_set_verbosity(verbosity: int):
     loguru.logger.add(
         sys.stderr,  # type: ignore
         format=(
-            "<green>{time:HH:mm:ss.SS}</green> | <level>{level}</level> \t|"
+            "<green>{time:HH:mm:ss.SS}</green> | <level>{level:8}</level> \t|"
             " <level>{message}</level>"
         ),
         level=verbosity_int_to_str(verbosity),
@@ -66,7 +78,7 @@ def loguru_tqdm_sink(verbosity: int):
     loguru.logger.add(
         lambda msg: tqdm.tqdm.write(msg, end=""),  # type: ignore
         format=(
-            "<green>{time:HH:mm:ss.SS}</green> | <level>{level}</level> \t|"
+            "<green>{time:HH:mm:ss.SS}</green> | <level>{level:8}</level> \t|"
             " <level>{message}</level>"
         ),
         level=verbosity_int_to_str(verbosity),
@@ -104,6 +116,18 @@ def verbosity_int_to_std_logging_lvl(verbosity: int) -> int:
     :param verbosity: Set the verbosity of the tqdm logger.
                       0 for >= INFO,
                       1 for >= DEBUG,
+
+    >>> verbosity_int_to_std_logging_lvl(0)
+    20
+    >>> verbosity_int_to_std_logging_lvl(1)
+    10
+    >>> verbosity_int_to_std_logging_lvl(2)
+    10
+    >>> verbosity_int_to_std_logging_lvl(3)
+    10
+    >>> verbosity_int_to_std_logging_lvl(-1)
+    Traceback (most recent call last):
+    RuntimeError: ...
     """
     if verbosity < 0:
         raise RuntimeError("verbosity must be >= 0")
